import * as _ from "lodash";
export function isNull(o) {
    return (o === null);
}
export function isObject(o) {
    return ((o !== null) && typeof o === 'object');
}
export function isEmpty(o) {
    if (isDefined(o)) {
        if (typeof o === 'string') {
            return o.length === 0;
        }
    }
    return false;
}
export function isDefined(o) {
    return (!isNullOrUndefined(o));
}
export function isUndefined(o) {
    return (o === undefined);
}
export function isNullOrUndefined(o) {
    return ((o === null) || (o === undefined));
}
export function isFunction(f) {
    return (isDefined(f) && typeof f === 'function');
}
export function isArray(o) {
    return (isDefined(o) && Array.isArray(o));
}
export function isString(o) {
    return (isDefined(o) && (typeof o === 'string' || o instanceof String));
}
export function isStringWithLength(o) {
    return (isString(o) && o.length > 0);
}
export function isArrayWithLength(o) {
    return (isArray(o) && o.length > 0);
}
export function isDate(o) {
    if (isStringWithLength(o)) {
        return /((^(10|12|0?[13578])([/])(3[01]|[12][0-9]|0?[1-9])([/])((1[8-9]\d{2})|([2-9]\d{3}))$)|(^(11|0?[469])([/])(30|[12][0-9]|0?[1-9])([/])((1[8-9]\d{2})|([2-9]\d{3}))$)|(^(0?2)([/])(2[0-8]|1[0-9]|0?[1-9])([/])((1[8-9]\d{2})|([2-9]\d{3}))$)|(^(0?2)([/])(29)([/])([2468][048]00)$)|(^(0?2)([/])(29)([/])([3579][26]00)$)|(^(0?2)([/])(29)([/])([1][89][0][48])$)|(^(0?2)([/])(29)([/])([2-9][0-9][0][48])$)|(^(0?2)([/])(29)([/])([1][89][2468][048])$)|(^(0?2)([/])(29)([/])([2-9][0-9][2468][048])$)|(^(0?2)([/])(29)([/])([1][89][13579][26])$)|(^(0?2)([/])(29)([/])([2-9][0-9][13579][26])$))/.test(o);
    }
    else {
        return _.isDate(o);
    }
}
export function isNumeric(o) {
    return !isNaN(parseFloat(o)) && isFinite(o);
}
export function isNumber(value) {
    return isNumeric(value);
}
export function isDecimal(value) {
    return (isNumeric(value) && (value % 1 !== 0));
}
export function isTrue(o) {
    return (isDefined(o) && typeof o === 'boolean' && o === true);
}
export function isFalse(o) {
    return (isDefined(o) && typeof o === 'boolean' && o === false);
}
export function isBoolean(o) {
    return (isDefined(o) && typeof o === 'boolean');
}
export function formatString(value, optValueArgs) {
    if (isStringWithLength(value) && isObject(optValueArgs)) {
        _.each(optValueArgs, function (valueObj, key) {
            var templateKey = ['{{', key, '}}'].join('');
            value = value.replace(templateKey, valueObj);
        });
    }
    return value;
}
export function isEmail(o) {
    var regExp = new RegExp('^[a-zA-Z0-9_.+-]+@[a-zA-Z0-9-]+\.[a-zA-Z0-9-.]+$');
    return (isString(o) && regExp.test(o));
}
export function camelCase(o) {
    if (isStringWithLength(o)) {
        return o.replace(/\s(.)/g, function ($1) {
            return $1.toUpperCase();
        })
            .replace(/\s/g, '')
            .replace(/^(.)/, function ($1) {
            return $1.toLowerCase();
        });
    }
    return o;
}
export function append(obj, char) {
    if (isUndefined(char)) {
        char = '/';
    }
    if (isString(obj)) {
        if (obj.charAt(obj.length - 1) !== char) {
            obj = obj.concat(char);
        }
    }
    return obj;
}
export function remove(obj, char) {
    if (isUndefined(char)) {
        char = '/';
    }
    if (isString(obj)) {
        if (obj.charAt(obj.length - 1) === char) {
            obj = obj.substring(0, obj.length - 1);
        }
    }
    return obj;
}
export function hasOwnProperty(o, prop) {
    return (isDefined(o) && isDefined(o[prop]));
}
export function init(obj, prop, value) {
    if (value === void 0) { value = undefined; }
    return (hasOwnProperty(obj, prop) ? obj[prop] : value);
}
export function calculate() {
    return {
        age: function (dob) {
            if (isDefined(dob)) {
                if (dob instanceof Date) {
                    var now = new Date(), year = now.getFullYear(), month = now.getMonth(), day = now.getDate(), age = year - dob.getFullYear();
                    if (month < (dob.getMonth() - 1)) {
                        age--;
                    }
                    if (((dob.getMonth() - 1) === month) && (day < dob.getDay())) {
                        age--;
                    }
                    return age;
                }
            }
            return undefined;
        }
    };
}
export function key() {
    var controlChar = [0, 8, 13], navigationChar = [35, 36, 37, 38, 39, 40];
    return {
        isNumber: function (which) {
            if (isDefined(which)) {
                return (!key().isNotNumber(which));
            }
            return false;
        },
        isNavigation: function (which) {
            if (isDefined(which)) {
                return navigationChar.indexOf(which) !== -1;
            }
            return false;
        },
        isNotNumber: function (which) {
            if (isDefined(which)) {
                return which < 44 || which > 57 || which === 47;
            }
            return false;
        },
        isControlChar: function (which) {
            return controlChar.indexOf(which) !== -1;
        },
        isNotControlChar: function (which) {
            return controlChar.indexOf(which) === -1;
        },
        alpha: function (value) {
            return (value === 32 || String.fromCharCode(value).match(/^[a-zA-Z]*$/));
        },
        isAlphaNumeric: function (value) {
            return (value === 32 || value === 35 || String.fromCharCode(value).match(/^[a-zA-Z0-9_]*$/));
        }
    };
}
export function pluck() {
    return {
        phoneNumber: function (value) {
            return value.replace(/[^0-9]/g, '');
        },
        decimals: function (value) {
            return value.indexOf('.') === -1 ? '' : value.replace(/^-?\d+(?=\.)/, '');
        },
        cardinal: function (value) {
            return value.replace(/(\.\d+)$/, '');
        },
        number: function (value) {
            return value.replace(/(\d)(?=(\d{3})+(?!\d))/g, '$1,');
        }
    };
}
export function find() {
    return {
        indicies: function (o, regexp) {
            if (regexp === void 0) { regexp = "[,]"; }
            var indicies = new Array();
            if (isStringWithLength(o)) {
                var exp = new RegExp(regexp, "g");
                if (!isNull(o.match(exp))) {
                    if (o.match(exp).length > 0) {
                        var match = void 0;
                        while ((match = exp.exec(o)) != null) {
                            indicies.push(match.index);
                        }
                    }
                }
            }
            return indicies;
        }
    };
}
export function convert() {
    return {
        toIntegerArray: function (o, regexp) {
            if (regexp === void 0) { regexp = "[,-]"; }
            var numbers = new Array();
            if (isStringWithLength(o)) {
                var indexes = find().indicies(o, regexp);
                if (!isArrayWithLength(indexes)) {
                    if (isNumber(o)) {
                        numbers.push(0);
                    }
                }
                else {
                    for (var i = 0; i < indexes.length; i++) {
                        if (o[i] === ',') {
                            numbers.push(parseInt(o[i - 1], 10));
                        }
                        else if (o[i] === '-') {
                            for (var j = parseInt(o[i - 1], 10); j <= parseInt(o[i + 1], 10); j++) {
                                numbers.push(j);
                            }
                        }
                    }
                }
            }
            return (_.uniq(numbers)).sort(function (n1, n2) { return n1 - n2; });
        }
    };
}
export default {
    append: append,
    calculate: calculate,
    camelCase: camelCase,
    convert: convert,
    find: find,
    formatString: formatString,
    hasOwnProperty: hasOwnProperty,
    init: init,
    isArray: isArray,
    isArrayWithLength: isArrayWithLength,
    isBoolean: isBoolean,
    isDate: isDate,
    isDefined: isDefined,
    isDecimal: isDecimal,
    isEmail: isEmail,
    isEmpty: isEmpty,
    isFalse: isFalse,
    isFunction: isFunction,
    isNull: isNull,
    isNullOrUndefined: isNullOrUndefined,
    isNumber: isNumber,
    isNumeric: isNumeric,
    isObject: isObject,
    isString: isString,
    isStringWithLength: isStringWithLength,
    isTrue: isTrue,
    isUndefined: isUndefined,
    key: key,
    pluck: pluck,
    remove: remove
};
//# sourceMappingURL=/Users/admin/Desktop/git/sandbox/typescript/src/library/library.js.map