import * as tslib_1 from "tslib";
import * as Library from "../../library/library";
import { Option } from "./option";
import { Base } from "../common/base";
var Table = (function (_super) {
    tslib_1.__extends(Table, _super);
    function Table(options, columns) {
        if (columns === void 0) { columns = []; }
        var _this = _super.call(this, options) || this;
        //
        // Setup Options
        //
        _this.options = new Option(Object.assign({}, options));
        //
        // Setup Columns
        //
        _this.columns = columns;
        return _this;
    }
    Object.defineProperty(Table.prototype, "options", {
        /**
         * options
         * @returns {any}
         */
        get: function () {
            return this._options;
        },
        /**
         * options
         * @param Option
         */
        set: function (options) {
            if (Library.isObject(options)) {
                this._options = options;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Table.prototype, "items", {
        /**
         * items
         * @returns {Array<Name>}
         */
        get: function () {
            return this._items;
        },
        /**
         * items
         * @param items
         */
        set: function (items) {
            var _this = this;
            if (Library.isArrayWithLength(items)) {
                this._items = items.sort(function (a, b) { return _this.compare(a, b, _this.options.column.sortBy); });
                this.render();
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Table.prototype, "columns", {
        /**
         * items
         * @returns {Array<Item>}
         */
        get: function () {
            return this._columns;
        },
        /**
         * columns
         * @param columns
         */
        set: function (columns) {
            var _this = this;
            if (Library.isArrayWithLength(columns)) {
                this._columns = columns.sort(function (a, b) { return _this.compare(a, b, _this.options.column.orderBy); });
            }
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Render()
     */
    Table.prototype.render = function () {
        var _this = this;
        //
        // Get Table Container
        //
        var container = document.getElementById("idc_container");
        var tbl = document.createElement("table");
        var tblBody = document.createElement("tbody");
        var tblHead = document.createElement("thead");
        //
        // Iterate through Object Properties
        //
        this.columns
            .filter(function (column) { return column.visible; })
            .forEach(function (column) {
            var th = document.createElement("th");
            th.innerHTML = "" + column.label;
            tblHead.appendChild(th);
        });
        tblHead.className = 'table-inverse';
        tbl.appendChild(tblHead);
        //
        // Table Attributes
        //
        tbl.className = "table table-bordered table-striped";
        //
        // Loop Through Names
        //
        this.items.forEach(function (name) {
            //
            // Create Row
            //
            var tr = document.createElement("tr");
            //
            // Iterate through Object Properties
            //
            _this.columns
                .filter(function (column) { return column.visible; })
                .forEach(function (column) {
                var td = document.createElement("td");
                var node = document.createTextNode("" + name[column.field]);
                td.appendChild(node);
                tr.appendChild(td);
            });
            //
            // Append Row
            //
            tblBody.appendChild(tr);
        });
        tbl.appendChild(tblBody);
        container.appendChild(tbl);
    };
    /**
     * compare()
     * @param a
     * @param b
     * @param prop
     * @returns {number}
     */
    Table.prototype.compare = function (a, b, prop) {
        if (a[prop] > b[prop]) {
            return 1;
        }
        if (a[prop] < b[prop]) {
            return -1;
        }
        return 0;
    };
    return Table;
}(Base));
export { Table };
//# sourceMappingURL=/Users/admin/Desktop/git/sandbox/typescript/src/model/generic/table.js.map